Module blaxel.core.client.models.preview_token
==============================================

Classes
-------

`PreviewToken(metadata: blaxel.core.client.types.Unset | ForwardRef('PreviewTokenMetadata') = <blaxel.core.client.types.Unset object>, spec: blaxel.core.client.types.Unset | ForwardRef('PreviewTokenSpec') = <blaxel.core.client.types.Unset object>)`
:   Token for a Preview
    
    Attributes:
        metadata (Union[Unset, PreviewTokenMetadata]): PreviewTokenMetadata
        spec (Union[Unset, PreviewTokenSpec]): Spec for a Preview Token
    
    Method generated by attrs for class PreviewToken.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `metadata`
    :

    `spec`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :